@@ -1,5 +1,6 @@
 import re
 import os
+import platform
 import ssl
 import time
 import shutil
@@ -246,6 +247,9 @@ class URLTarget(object):
             if msg.find('Unsupported URL') >= 0:
                 logging.debug('T%s - youtube-dl Error: %s', self.thread_id, msg)
                 return
+            if msg.find('no suitable InfoExtractor') >= 0:
+                logging.debug('T%s - youtube-dl Error: %s', self.thread_id, msg)
+                return
             # This is a critical error, with high probability the link can be downloaded at a later time.
             logging.error('T%s - youtube-dl Error: %s', self.thread_id, msg)
             self.url_target.youtube_dl_failed_with_error = True
@@ -446,7 +450,6 @@ class URLTarget(object):
             try:
                 ydl_results = ydl.download([url_to_download])
                 if ydl_results == 1:
-                    # return False
                     pass
                 elif self.file.module_name != 'index_mod-page':
                     self.file.saved_to = str(Path(self.destination) / self.filename)
@@ -454,9 +457,14 @@ class URLTarget(object):
 
                     self.success = True
                     return True
-            except Exception:
-                # return False
-                pass
+            except Exception as e:
+                logging.error(
+                    'T%s - Youtube-dl failed! Error: %s',
+                    self.thread_id,
+                    e,
+                )
+                self.youtube_dl_failed_with_error = True
+
             # if we want we could save ydl.cookiejar (Also the cookiejar of moodle-dl)
 
             if self.youtube_dl_failed_with_error is True:
@@ -550,7 +558,7 @@ class URLTarget(object):
 
         logging.debug('T%s - Creating a shortcut', self.thread_id)
         with open(self.file.saved_to, 'w+', encoding='utf-8') as shortcut:
-            if os.name == 'nt':
+            if os.name == 'nt' or platform.system() == "Darwin":
                 shortcut.write('[InternetShortcut]' + os.linesep)
                 shortcut.write('URL=' + self.file.content_fileurl + os.linesep)
             else:
@@ -582,7 +590,7 @@ class URLTarget(object):
 
         elif self.file.module_modname.startswith('url') and not ignore_attributes:
             self.file.saved_to = str(Path(self.destination) / (self.filename + '.desktop'))
-            if os.name == 'nt':
+            if os.name == 'nt' or platform.system() == "Darwin":
                 self.file.saved_to = str(Path(self.destination) / (self.filename + '.URL'))
 
             self.file.saved_to = self._rename_if_exists(self.file.saved_to)
